Index: test/mjsunit/es6/debug-promises/throw-finally-caught-all.js |
diff --git a/test/mjsunit/es6/debug-promises/throw-caught-all.js b/test/mjsunit/es6/debug-promises/throw-finally-caught-all.js |
similarity index 88% |
copy from test/mjsunit/es6/debug-promises/throw-caught-all.js |
copy to test/mjsunit/es6/debug-promises/throw-finally-caught-all.js |
index 3b7c48c1cff2ab8b96622cf2f52733a32683bffd..a3d45dce7798a8a04fa33ea6663cd2df04472109 100644 |
--- a/test/mjsunit/es6/debug-promises/throw-caught-all.js |
+++ b/test/mjsunit/es6/debug-promises/throw-finally-caught-all.js |
@@ -1,11 +1,12 @@ |
-// Copyright 2014 the V8 project authors. All rights reserved. |
+// Copyright 2016 the V8 project authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
// Flags: --expose-debug-as debug --allow-natives-syntax --promise-extra |
// Test debug events when we listen to all exceptions and |
// there is a catch handler for the exception thrown in a Promise. |
// We expect a normal Exception debug event to be triggered. |
Debug = debug.Debug; |
@@ -21,7 +22,10 @@ var p = new Promise(function(resolve, reject) { |
var q = p.chain( |
function() { |
log.push("throw"); |
- throw new Error("caught"); |
+ try { |
+ throw new Error("caught"); |
+ } finally { |
+ } |
}); |
q.catch( |
@@ -1,11 +1,12 @@ |
// Flags: --expose-debug-as debug --allow-natives-syntax --promise-extra |
// Test debug events when we listen to all exceptions and |
-// there is a catch handler for the exception thrown in a Promise. |
+// there is a catch handler for the exception thrown in a Promise, first |
+// caught by a try-finally, and immediately rethrown. |
// We expect a normal Exception debug event to be triggered. |
Debug = debug.Debug; |